@@ -31,6 +31,7 @@ class TcpdumpHelper:
             self.intf_name = self.intf_name.split('.')[0]
 
         tcpdump_flags = vflags
+        # pylint: disable=consider-using-f-string
         tcpdump_flags += ' -Z root'
         tcpdump_flags += ' -c %u' % packets if packets else ''
         tcpdump_flags += ' -w %s' % pcap_out if pcap_out else ''
@@ -49,8 +50,10 @@ class TcpdumpHelper:
             close_fds=True,
             shell=False)
 
-        if self.stream():
-            debug(f'tcpdump_helper stream fd {self.stream().fileno()} {self.intf_name}')
+        stream = self.stream()
+        if stream:
+            debug('tcpdump_helper stream fd %s %s' % (
+                stream.fileno(), self.intf_name))
 
         self.readbuf = ''
         self.set_blocking(blocking)
@@ -75,22 +78,24 @@ class TcpdumpHelper:
     def execute(self):
         """Run the helper and accumulate tcpdump output."""
         tcpdump_txt = ''
-        if self.stream():
+        stream = self.stream()
+        if stream:
             while True:
                 line = self.next_line()
                 if not line:
                     break
-                debug(f'tcpdump_helper fd {self.stream().fileno()} line "{line}"')
+                debug('tcpdump_helper fd %d line "%s"' % (stream.fileno(), line))
                 tcpdump_txt += line.strip()
         return tcpdump_txt
 
     def terminate(self):
         """Terminate the helper."""
-        if not self.pipe or not self.stream():
+        stream = self.stream()
+        if not self.pipe or not stream:
             return -1
 
         try:
-            debug(f'tcpdump_helper terminate fd {self.stream().fileno()}')
+            debug('tcpdump_helper terminate fd %s' % stream.fileno())
             self.pipe.terminate()
             result = self.pipe.wait()
             if result == 124:
